@@ -1,14 +1,12 @@
-from validate import is_rgb
-import json
+from colorcodetools.rgb.validate import is_rgb, is_single_rgb
 from typing import Union
+from colorcodetools.rgb.config import config
 
 def invert_rgb(rgb: str, a: float = 1.0, prefix: bool = True) -> Union[bool, str]:
     check_rgb: bool = is_rgb(rgb, a)
     if not check_rgb:
         return False
-    with open('config.json', 'r') as configFile:
-        config_data = json.load(configFile)
-        configFile.close()
+    config_data = config()
     rgb: str = rgb.replace("(", "")
     rgb = rgb.replace(")", "")
     if prefix:
@@ -33,4 +31,10 @@ def invert_rgb(rgb: str, a: float = 1.0, prefix: bool = True) -> Union[bool, str
         inverted_rgb += str(a) + ")"
     return inverted_rgb
 
-print(invert_rgb("(255, 0, 0)", 1.0, prefix=False))
\ No newline at end of file
+def invert_single_rgb(rgb: int) -> Union[bool, int]:
+    check_rgb: bool = is_single_rgb(rgb)
+    if not check_rgb:
+        return False
+    config_data = config()
+    inverted_rgb: int = config_data[str(rgb).strip()]
+    return inverted_rgb
\ No newline at end of file
